@@ -131,15 +131,22 @@ namespace Breeze
 
     //____________________________________________________________________
     QColor Helper::sidePanelBackgroundColor( const QPalette& palette, QPalette::ColorGroup role ) const
-    { return KColorUtils::mix( palette.color( role, QPalette::Window ), palette.color( role, QPalette::Base ), 0.6 ); }
+    // { return KColorUtils::mix( palette.color( role, QPalette::Window ), palette.color( role, QPalette::Base ), 0.6 ); }
+    { return palette.color( role, QPalette::Window ); }
+
+    //____________________________________________________________________
+    QColor Helper::sidePanelForegroundColor( const QPalette& palette, QPalette::ColorGroup role ) const
+    { return palette.color( role, QPalette::WindowText ); }
 
     //____________________________________________________________________
     QPalette Helper::framePalette( const QPalette& palette ) const
     {
         QPalette copy( palette );
-        copy.setColor( QPalette::Disabled, QPalette::Window, frameBackgroundColor( palette, QPalette::Disabled ) );
-        copy.setColor( QPalette::Active, QPalette::Window, frameBackgroundColor( palette, QPalette::Active ) );
-        copy.setColor( QPalette::Inactive, QPalette::Window, frameBackgroundColor( palette, QPalette::Inactive ) );
+
+        const QList<QPalette::ColorGroup> groups = { QPalette::Disabled, QPalette::Active, QPalette::Inactive };
+        foreach( const QPalette::ColorGroup& group, groups )
+        { copy.setColor( group, QPalette::Window, frameBackgroundColor( palette, group ) ); }
+
         return copy;
     }
 
@@ -147,15 +154,13 @@ namespace Breeze
     QPalette Helper::sideViewPalette( const QPalette& palette ) const
     {
         QPalette copy( palette );
-        copy.setColor( QPalette::Disabled, QPalette::Base, sidePanelBackgroundColor( palette, QPalette::Disabled ) );
-        copy.setColor( QPalette::Active, QPalette::Base, sidePanelBackgroundColor( palette, QPalette::Active ) );
-        copy.setColor( QPalette::Inactive, QPalette::Base, sidePanelBackgroundColor( palette, QPalette::Inactive ) );
-
-//         // alter default text color
-//         copy.setColor( QPalette::Disabled, QPalette::Text, palette.color( QPalette::Disabled, QPalette::WindowText ) );
-//         copy.setColor( QPalette::Active, QPalette::Text, palette.color( QPalette::Active, QPalette::WindowText ) );
-//         copy.setColor( QPalette::Inactive, QPalette::Text, palette.color( QPalette::Inactive, QPalette::WindowText ) );
 
+        const QList<QPalette::ColorGroup> groups = { QPalette::Disabled, QPalette::Active, QPalette::Inactive };
+        foreach( const QPalette::ColorGroup& group, groups )
+        {
+            copy.setColor( group, QPalette::Base, sidePanelBackgroundColor( palette, group ) );
+            copy.setColor( group, QPalette::Text, sidePanelForegroundColor( palette, group ) );
+        }
 
         return copy;
     }
@@ -398,14 +403,13 @@ namespace Breeze
     QPalette Helper::disabledPalette( const QPalette& source, qreal ratio ) const
     {
 
-        QPalette out( source );
-        out.setColor( QPalette::Background, KColorUtils::mix( source.color( QPalette::Active, QPalette::Background ), source.color( QPalette::Disabled, QPalette::Background ), 1.0-ratio ) );
-        out.setColor( QPalette::Highlight, KColorUtils::mix( source.color( QPalette::Active, QPalette::Highlight ), source.color( QPalette::Disabled, QPalette::Highlight ), 1.0-ratio ) );
-        out.setColor( QPalette::WindowText, KColorUtils::mix( source.color( QPalette::Active, QPalette::WindowText ), source.color( QPalette::Disabled, QPalette::WindowText ), 1.0-ratio ) );
-        out.setColor( QPalette::ButtonText, KColorUtils::mix( source.color( QPalette::Active, QPalette::ButtonText ), source.color( QPalette::Disabled, QPalette::ButtonText ), 1.0-ratio ) );
-        out.setColor( QPalette::Text, KColorUtils::mix( source.color( QPalette::Active, QPalette::Text ), source.color( QPalette::Disabled, QPalette::Text ), 1.0-ratio ) );
-        out.setColor( QPalette::Button, KColorUtils::mix( source.color( QPalette::Active, QPalette::Button ), source.color( QPalette::Disabled, QPalette::Button ), 1.0-ratio ) );
-        return out;
+        QPalette copy( source );
+
+        const QList<QPalette::ColorRole> roles = { QPalette::Background, QPalette::Highlight, QPalette::WindowText, QPalette::ButtonText, QPalette::Text, QPalette::Button };
+        foreach( const QPalette::ColorRole& role, roles )
+        { copy.setColor( role, KColorUtils::mix( source.color( QPalette::Active, role ), source.color( QPalette::Disabled, role ), 1.0-ratio ) ); }
+
+        return copy;
     }
 
     //____________________________________________________________________
@@ -586,8 +590,11 @@ namespace Breeze
         qreal radius( frameRadius() );
 
         // shadow
-        if( shadow.isValid() && !sunken )
-        {
+        if( sunken ) {
+
+            frameRect.translate( 1, 1 );
+
+        } else if( shadow.isValid() ) {
 
             painter->setPen( QPen( shadow, 2 ) );
             painter->setBrush( Qt::NoBrush );
@@ -791,9 +798,14 @@ namespace Breeze
         const qreal radius( frameRadius() );
 
         // shadow
-        if( !sunken )
+        if( sunken )
         {
 
+            frameRect.translate(1, 1);
+            // painter->translate( 1, 1 );
+
+        } else {
+
             painter->setPen( QPen( shadow, 1 ) );
             painter->setBrush( Qt::NoBrush );
 
@@ -875,9 +887,13 @@ namespace Breeze
         frameRect.adjust( 1, 1, -1, -1 );
 
         // shadow
-        if( !sunken )
+        if( sunken )
         {
 
+            frameRect.translate( 1, 1 );
+
+        } else {
+
             painter->setPen( QPen( shadow, 1 ) );
             painter->setBrush( Qt::NoBrush );
             painter->drawEllipse( shadowRect( frameRect ).adjusted( -0.5, -0.5, 0.5, 0.5 ) );
@@ -1231,7 +1247,7 @@ namespace Breeze
     }
 
     //______________________________________________________________________________
-    void Helper::renderButton( QPainter* painter, const QRect& rect, const QColor& color, ButtonType buttonType, bool inverted ) const
+    void Helper::renderDecorationButton( QPainter* painter, const QRect& rect, const QColor& color, ButtonType buttonType, bool inverted ) const
     {
 
         painter->save();
@@ -1338,8 +1354,7 @@ namespace Breeze
     {
         #if BREEZE_HAVE_X11
         #if QT_VERSION >= 0x050000
-        static bool isX11 = QApplication::platformName() == QStringLiteral("xcb");
-        return isX11;
+        return QX11Info::isPlatformX11();
         #else
         return true;
         #endif
